pub type NextAssetId<T: Config<I>, I: 'static = ()> = StorageValue<_GeneratedPrefixForStorageNextAssetId<T, I>, T::AssetId, OptionQuery>;Expand description
The asset ID enforced for the next asset creation, if any present. Otherwise, this storage item has no effect.
Only read by crate::AutoIncAssetId: configure it as Config::AssetIdAllocator and
provide an initial value here to apply an auto-increment model to all new asset IDs.
The initial next asset ID can be set using the GenesisConfig or the
SetNextAssetId migration.
Storage type is [StorageValue] with value type T :: AssetId.
Aliased Type
pub struct NextAssetId<T: Config<I>, I: 'static = ()>(/* private fields */);